From: Vojtech Pavlik <vojtech@suse.cz>
To: Vojtech Pavlik <vojtech@suse.cz>
Cc: torvalds@transmeta.com, linux-kernel@vger.kernel.org
Subject: [patch] input: Turn numlock ON on HP HIL machines [6/13]
Date: Sat, 14 Jun 2003 22:40:52 +0200 [thread overview]
Message-ID: <20030614224052.E25997@ucw.cz> (raw)
In-Reply-To: <20030614224022.D25997@ucw.cz>; from vojtech@suse.cz on Sat, Jun 14, 2003 at 10:40:22PM +0200
You can pull this changeset from:
bk://kernel.bkbits.net/vojtech/input
===================================================================
ChangeSet@1.1215.104.23, 2003-06-09 14:06:54+02:00, deller@gmx.de
input: Turn on the NumLock ON by default on PARISC HP-HIL machines.
keyboard.c | 8 +++++---
1 files changed, 5 insertions(+), 3 deletions(-)
===================================================================
diff -Nru a/drivers/char/keyboard.c b/drivers/char/keyboard.c
--- a/drivers/char/keyboard.c Sat Jun 14 22:22:58 2003
+++ b/drivers/char/keyboard.c Sat Jun 14 22:22:58 2003
@@ -52,11 +52,13 @@
/*
* Some laptops take the 789uiojklm,. keys as number pad when NumLock is on.
* This seems a good reason to start with NumLock off. On PC9800 however there
* is no NumLock key and everyone expects the keypad to be used for numbers.
*/
-#ifdef CONFIG_X86_PC9800
+#if defined(CONFIG_X86_PC9800) || \
+ defined(CONFIG_PARISC) && (defined(CONFIG_KEYBOARD_HIL) || defined(CONFIG_KEYBOARD_HIL_OLD))
#define KBD_DEFLEDS (1 << VC_NUMLOCK)
#else
#define KBD_DEFLEDS 0
next prev parent reply other threads:[~2003-06-14 20:28 UTC|newest]
Thread overview: 47+ messages / expand[flat|nested] mbox.gz Atom feed top
2003-06-14 20:35 [patch] input: Implement device grabbing [1/13] Vojtech Pavlik
2003-06-14 20:36 ` [patch] input: Fix sunkbd keybit bitfield filling [2/13] Vojtech Pavlik
2003-06-14 20:37 ` [patch] input: Implement HID quirk for A4Tech mice [3/13] Vojtech Pavlik
2003-06-14 20:39 ` [patch] input: Add hiragana/katakana keys to atkbd.c [4/13] Vojtech Pavlik
2003-06-14 20:40 ` [patch] input: Add PCI PS/2 controller support [5/13] Vojtech Pavlik
2003-06-14 20:40 ` Vojtech Pavlik [this message]
2003-06-14 20:41 ` [patch] input: Add keys for HP HIL [7/13] Vojtech Pavlik
2003-06-14 20:42 ` [patch] input: Fix CLOCK_TICK_RATE usage ... [8/13] Vojtech Pavlik
2003-06-14 20:43 ` [patch] input: Fix i8042 interrupts on I2000 ia64 machines [9/13] Vojtech Pavlik
2003-06-14 20:44 ` [patch] input: Fix sending reports in USB HID [10/13] Vojtech Pavlik
2003-06-14 20:45 ` [patch] input: Fix hiddev_ioctl() [11/13] Vojtech Pavlik
2003-06-14 20:45 ` [patch] input: Fix minor errors in input-programming.txt [12/13] Vojtech Pavlik
2003-06-14 20:46 ` [patch] input: Add Synaptics touchpad support [13/13] Vojtech Pavlik
2003-06-14 21:05 ` [patch] input: Fix CLOCK_TICK_RATE usage ... [8/13] Riley Williams
2003-06-14 21:14 ` Vojtech Pavlik
2003-06-15 10:51 ` Riley Williams
2003-06-16 18:57 ` David Mosberger
2003-06-17 22:11 ` Riley Williams
2003-06-17 22:19 ` David Mosberger
2003-06-17 22:21 ` Vojtech Pavlik
2003-06-17 22:34 ` David Mosberger
2003-06-17 22:42 ` Vojtech Pavlik
2003-06-17 22:48 ` Russell King
2003-06-17 22:53 ` Vojtech Pavlik
2003-06-19 12:13 ` David Woodhouse
2003-06-19 14:19 ` Russell King
2003-06-17 23:08 ` David Mosberger
2003-06-17 23:14 ` Vojtech Pavlik
2003-06-17 23:24 ` David Mosberger
2003-06-17 23:31 ` Vojtech Pavlik
2003-06-18 0:47 ` george anzinger
2003-06-25 8:03 ` Riley Williams
2003-06-25 17:20 ` David Mosberger
2003-06-25 17:56 ` Riley Williams
2003-06-25 18:49 ` David Mosberger
2003-06-25 19:58 ` Vojtech Pavlik
2003-06-25 20:09 ` David Mosberger
2003-06-25 20:25 ` Assorted warnings while building 2.5.73 J.C. Wren
2003-06-18 14:47 ` [patch] input: Fix CLOCK_TICK_RATE usage ... [8/13] Hollis Blanchard
2003-06-18 18:50 ` David Mosberger
2003-06-17 22:21 ` Russell King
2003-06-17 22:38 ` Vojtech Pavlik
2003-06-18 0:46 ` george anzinger
2003-06-18 1:00 ` george anzinger
2003-06-14 20:51 ` [patch] input: Add PCI PS/2 controller support [5/13] Oliver Neukum
2003-06-14 21:03 ` Vojtech Pavlik
2003-06-14 21:04 ` Russell King
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=20030614224052.E25997@ucw.cz \
--to=vojtech@suse.cz \
--cc=linux-kernel@vger.kernel.org \
--cc=torvalds@transmeta.com \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
@@ -52,11 +52,13 @@
/*
* Some laptops take the 789uiojklm,. keys as number pad when NumLock is on.
- * This seems a good reason to start with NumLock off. On PC9800 however there
- * is no NumLock key and everyone expects the keypad to be used for numbers.
+ * This seems a good reason to start with NumLock off. On PC9800 and HIL keyboards
+ * of PARISC machines however there is no NumLock key and everyone expects the keypad
+ * to be used for numbers.
*/
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox